==> owncloud-8.2.2p3.tgz: owncloud/core/l10n/km.js <==
OC.L10N.register(
    "core",
    {
    "Unknown filetype" : "មិន​ស្គាល់​ប្រភេទ​ឯកសារ",
    "Invalid image" : "រូបភាព​មិន​ត្រឹម​ត្រូវ",
    "Sunday" : "ថ្ងៃអាទិត្យ",
    "Monday" : "ថ្ងៃចន្ទ",
    "Tuesday" : "ថ្ងៃអង្គារ",
    "Wednesday" : "ថ្ងៃពុធ",
    "Thursday" : "ថ្ងៃព្រហស្បតិ៍",
    "Friday" : "ថ្ងៃសុក្រ",
    "Saturday" : "ថ្ងៃសៅរ៍",
    "Sun." : "អាទិត្យ",
    "Mon." : "ចន្ទ",
    "Tue." : "អង្គារ",
    "Wed." : "ពុធ",
    "Thu." : "ព្រហ.",
    "Fri." : "សុក្រ",
    "Sat." : "សៅរ៍",
    "January" : "ខែមករា",
    "February" : "ខែកុម្ភៈ",
    "March" : "ខែមីនា",
    "April" : "ខែមេសា",
    "May" : "ខែឧសភា",
    "June" : "ខែមិថុនា",
    "July" : "ខែកក្កដា",
    "August" : "ខែសីហា",
    "September" : "ខែកញ្ញា",
    "October" : "ខែតុលា",
    "November" : "ខែវិច្ឆិកា",
    "December" : "ខែធ្នូ",
    "Jan." : "មករា",
    "Feb." : "កុម្ភៈ",
    "Mar." : "មីនា",
    "Apr." : "មេសា",
    "May." : "ឧសភា",
    "Jun." : "មិថុនា",
    "Jul." : "កក្កដា",
    "Aug." : "សីហា",
    "Sep." : "កញ្ញា",
    "Oct." : "តុលា",
    "Nov." : "វិច្ឆិកា",
    "Dec." : "ធ្នូ",
    "Settings" : "ការកំណត់",
    "Saving..." : "កំពុង​រក្សាទុក",
    "seconds ago" : "វិនាទី​មុន",
    "No" : "ទេ",
    "Yes" : "ព្រម",
    "Choose" : "ជ្រើស",
    "Ok" : "ព្រម",
    "New Files" : "ឯកសារ​ថ្មី",
    "Already existing files" : "មាន​ឯកសារ​នេះ​រួច​ហើយ",
    "Cancel" : "លើកលែង",
    "Continue" : "បន្ត",
    "(all selected)" : "(បាន​ជ្រើស​ទាំង​អស់)",
    "({count} selected)" : "(បាន​ជ្រើស {count})",
    "Very weak password" : "ពាក្យ​សម្ងាត់​ខ្សោយ​ណាស់",
    "Weak password" : "ពាក្យ​សម្ងាត់​ខ្សោយ",
    "So-so password" : "ពាក្យ​សម្ងាត់​ធម្មតា",
    "Good password" : "ពាក្យ​សម្ងាត់​ល្អ",
    "Strong password" : "ពាក្យ​សម្ងាត់​ខ្លាំង",
    "Shared" : "បាន​ចែក​រំលែក",
    "Error" : "កំហុស",
    "Error while sharing" : "កំហុស​ពេល​ចែក​រំលែក",
    "Error while unsharing" : "កំពុង​ពេល​លែង​ចែក​រំលែក",
    "Error while changing permissions" : "មាន​កំហុស​នៅ​ពេល​ប្ដូរ​សិទ្ធិ",
    "Set expiration date" : "កំណត់​ពេល​ផុត​កំណត់",
    "Expiration date" : "ពេល​ផុត​កំណត់",
    "Sending ..." : "កំពុង​ផ្ញើ ...",
    "Email sent" : "បាន​ផ្ញើ​អ៊ីមែល",
    "Resharing is not allowed" : "មិន​អនុញ្ញាត​ឲ្យ​មាន​ការ​ចែក​រំលែក​ឡើង​វិញ",
    "Password protect" : "ការ​ពារ​ដោយ​ពាក្យ​សម្ងាត់",
    "Password" : "ពាក្យសម្ងាត់",
    "Send" : "ផ្ញើ",
    "Shared with you and the group {group} by {owner}" : "បាន​ចែក​រំលែក​ជាមួយ​អ្នក និង​ក្រុម {group} ដោយ {owner}",
    "Shared with you by {owner}" : "បាន​ចែក​រំលែក​ជាមួយ​អ្នក​ដោយ {owner}",
    "Shared in {item} with {user}" : "បាន​ចែក​រំលែក​ក្នុង {item} ជាមួយ {user}",
    "group" : "ក្រុម",
    "Unshare" : "លែង​ចែក​រំលែក",
    "can share" : "អាច​ចែក​រំលែក",
    "can edit" : "អាច​កែប្រែ",
    "create" : "បង្កើត",
    "delete" : "លុប",
    "access control" : "សិទ្ធិ​បញ្ជា",
    "Share" : "ចែក​រំលែក",
    "Warning" : "បម្រាម",
    "The object type is not specified." : "មិន​បាន​កំណត់​ប្រភេទ​វត្ថុ។",
    "Delete" : "លុប",
    "Add" : "បញ្ចូល",
    "Please reload the page." : "សូម​ផ្ទុក​ទំព័រ​នេះ​ឡើង​វិញ។",
    "New password" : "ពាក្យ​សម្ងាត់​ថ្មី",
    "Reset password" : "កំណត់​ពាក្យ​សម្ងាត់​ម្ដង​ទៀត",
    "Personal" : "ផ្ទាល់​ខ្លួន",
    "Users" : "អ្នកប្រើ",
    "Apps" : "កម្មវិធី",
    "Admin" : "អ្នក​គ្រប់​គ្រង",
    "Help" : "ជំនួយ",
    "Access forbidden" : "បាន​ហាមឃាត់​ការ​ចូល",
    "Create an <strong>admin account</strong>" : "បង្កើត​<strong>គណនី​អភិបាល</strong>",
    "Username" : "ឈ្មោះ​អ្នកប្រើ",
    "Storage & database" : "ឃ្លាំង​ផ្ទុក & មូលដ្ឋាន​ទិន្នន័យ",
    "Data folder" : "ថត​ទិន្នន័យ",
    "Configure the database" : "កំណត់​សណ្ឋាន​មូលដ្ឋាន​ទិន្នន័យ",
    "Database user" : "អ្នក​ប្រើ​មូលដ្ឋាន​ទិន្នន័យ",
    "Database password" : "ពាក្យ​សម្ងាត់​មូលដ្ឋាន​ទិន្នន័យ",
    "Database name" : "ឈ្មោះ​មូលដ្ឋាន​ទិន្នន័យ",
    "Database host" : "ម៉ាស៊ីន​មូលដ្ឋាន​ទិន្នន័យ",
    "Finish setup" : "បញ្ចប់​ការ​ដំឡើង",
    "Finishing …" : "កំពុង​បញ្ចប់ ...",
    "Log out" : "ចាក​ចេញ",
    "Search" : "ស្វែង​រក",
    "Log in" : "ចូល",
    "remember" : "ចងចាំ",
    "Alternative Logins" : "ការ​ចូល​ជំនួស"
},
"nplurals=1; plural=0;");

==> owncloud-10.0.7.tgz: owncloud/core/l10n/km.js <==
OC.L10N.register(
    "core",
    {
    "Unknown filetype" : "មិន​ស្គាល់​ប្រភេទ​ឯកសារ",
    "Invalid image" : "រូបភាព​មិន​ត្រឹម​ត្រូវ",
    "Sunday" : "ថ្ងៃអាទិត្យ",
    "Monday" : "ថ្ងៃចន្ទ",
    "Tuesday" : "ថ្ងៃអង្គារ",
    "Wednesday" : "ថ្ងៃពុធ",
    "Thursday" : "ថ្ងៃព្រហស្បតិ៍",
    "Friday" : "ថ្ងៃសុក្រ",
    "Saturday" : "ថ្ងៃសៅរ៍",
    "Sun." : "អាទិត្យ",
    "Mon." : "ចន្ទ",
    "Tue." : "អង្គារ",
    "Wed." : "ពុធ",
    "Thu." : "ព្រហ.",
    "Fri." : "សុក្រ",
    "Sat." : "សៅរ៍",
    "January" : "ខែមករា",
    "February" : "ខែកុម្ភៈ",
    "March" : "ខែមីនា",
    "April" : "ខែមេសា",
    "May" : "ខែឧសភា",
    "June" : "ខែមិថុនា",
    "July" : "ខែកក្កដា",
    "August" : "ខែសីហា",
    "September" : "ខែកញ្ញា",
    "October" : "ខែតុលា",
    "November" : "ខែវិច្ឆិកា",
    "December" : "ខែធ្នូ",
    "Jan." : "មករា",
    "Feb." : "កុម្ភៈ",
    "Mar." : "មីនា",
    "Apr." : "មេសា",
    "May." : "ឧសភា",
    "Jun." : "មិថុនា",
    "Jul." : "កក្កដា",
    "Aug." : "សីហា",
    "Sep." : "កញ្ញា",
    "Oct." : "តុលា",
    "Nov." : "វិច្ឆិកា",
    "Dec." : "ធ្នូ",
    "Settings" : "ការកំណត់",
    "Saving..." : "កំពុង​រក្សាទុក",
    "seconds ago" : "វិនាទី​មុន",
    "No" : "ទេ",
    "Yes" : "ព្រម",
    "Choose" : "ជ្រើស",
    "Ok" : "ព្រម",
    "New Files" : "ឯកសារ​ថ្មី",
    "Already existing files" : "មាន​ឯកសារ​នេះ​រួច​ហើយ",
    "Cancel" : "លើកលែង",
    "Continue" : "បន្ត",
    "(all selected)" : "(បាន​ជ្រើស​ទាំង​អស់)",
    "({count} selected)" : "(បាន​ជ្រើស {count})",
    "Very weak password" : "ពាក្យ​សម្ងាត់​ខ្សោយ​ណាស់",
    "Weak password" : "ពាក្យ​សម្ងាត់​ខ្សោយ",
    "So-so password" : "ពាក្យ​សម្ងាត់​ធម្មតា",
    "Good password" : "ពាក្យ​សម្ងាត់​ល្អ",
    "Strong password" : "ពាក្យ​សម្ងាត់​ខ្លាំង",
    "Shared" : "បាន​ចែក​រំលែក",
    "Error" : "កំហុស",
    "Error while sharing" : "កំហុស​ពេល​ចែក​រំលែក",
    "Error while unsharing" : "កំពុង​ពេល​លែង​ចែក​រំលែក",
    "Set expiration date" : "កំណត់​ពេល​ផុត​កំណត់",
    "Expiration date" : "ពេល​ផុត​កំណត់",
    "Edit" : "កែប្រែ",
    "Remove" : "ដកចេញ",
    "Password" : "ពាក្យសម្ងាត់",
    "Name" : "ឈ្មោះ",
    "Save" : "រក្សាទុក",
    "Sending ..." : "កំពុង​ផ្ញើ ...",
    "Email sent" : "បាន​ផ្ញើ​អ៊ីមែល",
    "Shared with you and the group {group} by {owner}" : "បាន​ចែក​រំលែក​ជាមួយ​អ្នក និង​ក្រុម {group} ដោយ {owner}",
    "Shared with you by {owner}" : "បាន​ចែក​រំលែក​ជាមួយ​អ្នក​ដោយ {owner}",
    "group" : "ក្រុម",
    "Unshare" : "លែង​ចែក​រំលែក",
    "can share" : "អាច​ចែក​រំលែក",
    "can edit" : "អាច​កែប្រែ",
    "create" : "បង្កើត",
    "delete" : "លុប",
    "access control" : "សិទ្ធិ​បញ្ជា",
    "Share" : "ចែក​រំលែក",
    "Resharing is not allowed" : "មិន​អនុញ្ញាត​ឲ្យ​មាន​ការ​ចែក​រំលែក​ឡើង​វិញ",
    "Warning" : "បម្រាម",
    "Delete" : "លុប",
    "Rename" : "ប្ដូរ​ឈ្មោះ",
    "The object type is not specified." : "មិន​បាន​កំណត់​ប្រភេទ​វត្ថុ។",
    "Add" : "បញ្ចូល",
    "Please reload the page." : "សូម​ផ្ទុក​ទំព័រ​នេះ​ឡើង​វិញ។",
    "Personal" : "ផ្ទាល់​ខ្លួន",
    "Users" : "អ្នកប្រើ",
    "Apps" : "កម្មវិធី",
    "Admin" : "អ្នក​គ្រប់​គ្រង",
    "Help" : "ជំនួយ",
    "Access forbidden" : "បាន​ហាមឃាត់​ការ​ចូល",
    "Create an <strong>admin account</strong>" : "បង្កើត​<strong>គណនី​អភិបាល</strong>",
    "Username" : "ឈ្មោះ​អ្នកប្រើ",
    "Storage & database" : "ឃ្លាំង​ផ្ទុក & មូលដ្ឋាន​ទិន្នន័យ",
    "Data folder" : "ថត​ទិន្នន័យ",
    "Configure the database" : "កំណត់​សណ្ឋាន​មូលដ្ឋាន​ទិន្នន័យ",
    "Database user" : "អ្នក​ប្រើ​មូលដ្ឋាន​ទិន្នន័យ",
    "Database password" : "ពាក្យ​សម្ងាត់​មូលដ្ឋាន​ទិន្នន័យ",
    "Database name" : "ឈ្មោះ​មូលដ្ឋាន​ទិន្នន័យ",
    "Database host" : "ម៉ាស៊ីន​មូលដ្ឋាន​ទិន្នន័យ",
    "Finish setup" : "បញ្ចប់​ការ​ដំឡើង",
    "Finishing …" : "កំពុង​បញ្ចប់ ...",
    "Log out" : "ចាក​ចេញ",
    "Search" : "ស្វែង​រក",
    "Log in" : "ចូល",
    "Alternative Logins" : "ការ​ចូល​ជំនួស",
    "New password" : "ពាក្យ​សម្ងាត់​ថ្មី",
    "Reset password" : "កំណត់​ពាក្យ​សម្ងាត់​ម្ដង​ទៀត"
},
"nplurals=1; plural=0;");
